django-usertools
================

**django-usertools** is a fire-and-forget enhancement to the Django user admin.


Features
--------

* Send invitation emails to your fellow admin users, allowing them to choose their own password on first login.
* Search through user lists using integrated [django-watson](https://github.com/etianen/django-watson) search.
* Batch admin actions for managing users and groups.
* Optional password reset feature for the admin site.


Documentation
-------------

Please read the [Getting Started][] guide for more information.

[Getting Started]: https://github.com/etianen/django-usertools/wiki
    "Getting started with django-usertools"
    
Download instructions, bug reporting and links to full documentation can be
found at the [main project website][].

[main project website]: http://github.com/etianen/django-usertools
    "django-usertools on GitHub"

You can keep up to date with the latest announcements by joining the
[django-usertools discussion group][].

[django-usertools discussion group]: http://groups.google.com/group/django-usertools
    "django-usertools Google Group"

    
More information
----------------

The django-usertools project was developed by Dave Hall. You can get the code
from the [django-usertools project site][].

[django-usertools project site]: http://github.com/etianen/django-usertools
    "django-usertools on GitHub"
    
Dave Hall is a freelance web developer, based in Cambridge, UK. You can usually
find him on the Internet in a number of different places:

*   [Website](http://www.etianen.com/ "Dave Hall's homepage")
*   [Twitter](http://twitter.com/etianen "Dave Hall on Twitter")
*   [Google Profile](http://www.google.com/profiles/david.etianen "Dave Hall's Google profile")